@@ -1,7 +1,7 @@
 import re
-from . import utilities
+#from . import utilities
 from doreah import tsv, settings
-from .globalconf import datadir
+from .globalconf import data_dir
 import pkg_resources
 
 # need to do this as a class so it can retain loaded settings from file
@@ -13,7 +13,7 @@ class CleanerAgent:
 		self.updateRules()
 
 	def updateRules(self):
-		raw = tsv.parse_all(datadir("rules"),"string","string","string","string")
+		raw = tsv.parse_all(data_dir["rules"](),"string","string","string","string")
 		self.rules_belongtogether = [b for [a,b,c,d] in raw if a=="belongtogether"]
 		self.rules_notanartist = [b for [a,b,c,d] in raw if a=="notanartist"]
 		self.rules_replacetitle = {b.lower():c for [a,b,c,d] in raw if a=="replacetitle"}
@@ -35,12 +35,12 @@ class CleanerAgent:
 			reqartists, allartists = self.rules_addartists[title.lower()]
 			reqartists = reqartists.split("␟")
 			allartists = allartists.split("␟")
-			if set(reqartists).issubset(set(a.lower() for a in artists)):
+			if set(reqartists).issubset({a.lower() for a in artists}):
 				artists += allartists
 		elif title.lower() in self.rules_fixartists:
 			allartists = self.rules_fixartists[title.lower()]
 			allartists = allartists.split("␟")
-			if len(set(a.lower() for a in allartists) & set(a.lower() for a in artists)) > 0:
+			if len({a.lower() for a in allartists} & {a.lower() for a in artists}) > 0:
 				artists = allartists
 		artists = list(set(artists))
 		artists.sort()
@@ -48,6 +48,8 @@ class CleanerAgent:
 		return (artists,title)
 
 	def removespecial(self,s):
+		if isinstance(s,list):
+			return [self.removespecial(se) for se in s]
 		s = s.replace("\t","").replace("␟","").replace("\n","")
 		s = re.sub(" +"," ",s)
 		return s
@@ -59,14 +61,21 @@ class CleanerAgent:
 		return (a in confirmed)
 
 	#Delimiters used for extra artists, even when in the title field
-	delimiters_feat = ["ft.","ft","feat.","feat","featuring","Ft.","Ft","Feat.","Feat","Featuring"]
+	#delimiters_feat = ["ft.","ft","feat.","feat","featuring","Ft.","Ft","Feat.","Feat","Featuring"]
+	delimiters_feat = settings.get_settings("DELIMITERS_FEAT")
 	#Delimiters in informal artist strings, spaces expected around them
-	delimiters = ["vs.","vs","&"]
+	#delimiters = ["vs.","vs","&"]
+	delimiters = settings.get_settings("DELIMITERS_INFORMAL")
 	#Delimiters used specifically to tag multiple artists when only one tag field is available, no spaces used
-	delimiters_formal = ["; ",";","/"]
+	#delimiters_formal = ["; ",";","/"]
+	delimiters_formal = settings.get_settings("DELIMITERS_FORMAL")
 
 	def parseArtists(self,a):
 
+		if isinstance(a,list):
+			res = [self.parseArtists(art) for art in a]
+			return [a for group in res for a in group]
+
 		if a.strip() in settings.get_settings("INVALID_ARTISTS"):
 			return []
 
@@ -168,7 +177,7 @@ class CollectorAgent:
 	# rules_include			dict: credited artist -> all real artists
 
 	def updateRules(self):
-		raw = tsv.parse_all(datadir("rules"),"string","string","string")
+		raw = tsv.parse_all(data_dir["rules"](),"string","string","string")
 		self.rules_countas = {b:c for [a,b,c] in raw if a=="countas"}
 		self.rules_countas_id = {}
 		self.rules_include = {} #Twice the memory, double the performance!
@@ -196,9 +205,7 @@ class CollectorAgent:
 
 	# get all credited artists for the artists given
 	def getCreditedList(self,artists):
-		updatedArtists = []
-		for artist in artists:
-			updatedArtists.append(self.getCredited(artist))
+		updatedArtists = [self.getCredited(artist) for artist in artists]
 		return list(set(updatedArtists))
 
 	# get artists who the given artist is given credit for
@@ -208,7 +215,7 @@ class CollectorAgent:
 	# this function is there to check for artists that we should include in the
 	# database even though they never have any scrobble.
 	def getAllArtists(self):
-		return list(set([self.rules_countas[a] for a in self.rules_countas]))
+		return list({self.rules_countas[a] for a in self.rules_countas})
 		# artists that count can be nonexisting (counting HyunA as 4Minute even
 		# though 4Minute has never been listened to)
 		# but artists that are counted as someone else are only relevant if they
@@ -229,6 +236,6 @@ def flatten(lis):
 		if isinstance(l, str):
 			newlist.append(l)
 		else:
-			newlist = newlist + l
+			newlist += l
 
 	return list(set(newlist))
