@@ -10,7 +10,7 @@ from .malojauri import uri_to_internal, internal_to_uri, compose_querystring
 from .thirdparty import proxy_scrobble_all
 
 from .__pkginfo__ import version
-from .globalconf import datadir
+from .globalconf import data_dir
 
 # doreah toolkit
 from doreah.logging import log
@@ -68,7 +68,7 @@ ARTISTS_NORMALIZED = []
 ARTISTS_NORMALIZED_SET = set()
 TRACKS_NORMALIZED_SET = set()
 
-MEDALS = {}	#literally only changes once per year, no need to calculate that on the fly
+MEDALS_ARTISTS = {}	#literally only changes once per year, no need to calculate that on the fly
 MEDALS_TRACKS = {}
 WEEKLY_TOPTRACKS = {}
 WEEKLY_TOPARTISTS = {}
@@ -83,7 +83,7 @@ lastsync = 0
 
 
 try:
-	with open(datadir("known_servers.yml"),"r") as f:
+	with open(data_dir['state']("known_servers.yml"),"r") as f:
 		KNOWN_SERVERS = set(yaml.safe_load(f))
 except:
 	KNOWN_SERVERS = set()
@@ -91,7 +91,7 @@ except:
 
 def add_known_server(url):
 	KNOWN_SERVERS.add(url)
-	with open(datadir("known_servers.yml"),"w") as f:
+	with open(data_dir['state']("known_servers.yml"),"w") as f:
 		f.write(yaml.dump(list(KNOWN_SERVERS)))
 
 
@@ -99,9 +99,9 @@ def add_known_server(url):
 ### symmetric keys are fine for now since we hopefully use HTTPS
 def loadAPIkeys():
 	global clients
-	tsv.create(datadir("clients/authenticated_machines.tsv"))
+	tsv.create(data_dir['clients']("authenticated_machines.tsv"))
 	#createTSV("clients/authenticated_machines.tsv")
-	clients = tsv.parse(datadir("clients/authenticated_machines.tsv"),"string","string")
+	clients = tsv.parse(data_dir['clients']("authenticated_machines.tsv"),"string","string")
 	#clients = parseTSV("clients/authenticated_machines.tsv","string","string")
 	log("Authenticated Machines: " + ", ".join([m[1] for m in clients]))
 
@@ -149,10 +149,9 @@ def createScrobble(artists,title,time,album=None,duration=None,volatile=False):
 	i = getTrackID(artists,title)
 
 	# idempotence
-	if time in SCROBBLESDICT:
-		if i == SCROBBLESDICT[time].track:
-			dblock.release()
-			return get_track_dict(TRACKS[i])
+	if time in SCROBBLESDICT and i == SCROBBLESDICT[time].track:
+		dblock.release()
+		return get_track_dict(TRACKS[i])
 	# timestamp as unique identifier
 	while (time in SCROBBLESDICT):
 		time += 1
@@ -192,35 +191,31 @@ def getArtistID(name):
 	if obj_normalized in ARTISTS_NORMALIZED_SET:
 		return ARTISTS_NORMALIZED.index(obj_normalized)
 
-	else:
-		i = len(ARTISTS)
-		ARTISTS.append(obj)
-		ARTISTS_NORMALIZED_SET.add(obj_normalized)
-		ARTISTS_NORMALIZED.append(obj_normalized)
+	i = len(ARTISTS)
+	ARTISTS.append(obj)
+	ARTISTS_NORMALIZED_SET.add(obj_normalized)
+	ARTISTS_NORMALIZED.append(obj_normalized)
 
-		# with a new artist added, we might also get new artists that they are credited as
-		cr = coa.getCredited(name)
-		getArtistID(cr)
+	# with a new artist added, we might also get new artists that they are credited as
+	cr = coa.getCredited(name)
+	getArtistID(cr)
 
-		coa.updateIDs(ARTISTS)
+	coa.updateIDs(ARTISTS)
 
-		return i
+	return i
 
 def getTrackID(artists,title):
-	artistset = set()
-	for a in artists:
-		artistset.add(getArtistID(name=a))
+	artistset = {getArtistID(name=a) for a in artists}
 	obj = Track(artists=frozenset(artistset),title=title)
 	obj_normalized = Track(artists=frozenset(artistset),title=normalize_name(title))
 
 	if obj_normalized in TRACKS_NORMALIZED_SET:
 		return TRACKS_NORMALIZED.index(obj_normalized)
-	else:
-		i = len(TRACKS)
-		TRACKS.append(obj)
-		TRACKS_NORMALIZED_SET.add(obj_normalized)
-		TRACKS_NORMALIZED.append(obj_normalized)
-		return i
+	i = len(TRACKS)
+	TRACKS.append(obj)
+	TRACKS_NORMALIZED_SET.add(obj_normalized)
+	TRACKS_NORMALIZED.append(obj_normalized)
+	return i
 
 import unicodedata
 
@@ -269,9 +264,9 @@ def api_key_correct(request):
 
 def get_scrobbles(**keys):
 	r = db_query(**{k:keys[k] for k in keys if k in ["artist","artists","title","since","to","within","timerange","associated","track"]})
-	offset = (keys.get('page') * keys.get('perpage')) if keys.get('perpage') is not math.inf else 0
-	r = r[offset:]
-	if keys.get('perpage') is not math.inf: r = r[:keys.get('perpage')]
+	#offset = (keys.get('page') * keys.get('perpage')) if keys.get('perpage') is not math.inf else 0
+	#r = r[offset:]
+	#if keys.get('perpage') is not math.inf: r = r[:keys.get('perpage')]
 	return r
 
 
@@ -330,11 +325,7 @@ def get_scrobbles_num(**keys):
 
 def get_tracks(artist=None):
 
-	if artist is not None:
-		artistid = ARTISTS.index(artist)
-	else:
-		artistid = None
-
+	artistid = ARTISTS.index(artist) if artist is not None else None
 	# Option 1
 	return [get_track_dict(t) for t in TRACKS if (artistid in t.artists) or (artistid==None)]
 
@@ -477,7 +468,7 @@ def artistInfo(artist):
 			"scrobbles":scrobbles,
 			"position":position,
 			"associated":others,
-			"medals":{"gold":[],"silver":[],"bronze":[],**MEDALS.get(artist,{})},
+			"medals":{"gold":[],"silver":[],"bronze":[],**MEDALS_ARTISTS.get(artist,{})},
 			"topweeks":WEEKLY_TOPARTISTS.get(artist,0)
 		}
 	except:
@@ -577,7 +568,7 @@ def incoming_scrobble(artists,title,album=None,duration=None,time=None,fix=True)
 
 	log("Incoming scrobble (): ARTISTS: " + str(artists) + ", TRACK: " + title,module="debug")
 	if fix:
-		(artists,title) = cla.fullclean("/".join(artists),title)
+		(artists,title) = cla.fullclean(artists,title)
 	trackdict = createScrobble(artists,title,time,album,duration)
 
 	sync()
@@ -639,7 +630,7 @@ def check_issues():
 				duplicates.append((a,ar))
 
 		st = st.replace("&","").replace("and","").replace("with","").strip()
-		if st != "" and st != a:
+		if st not in ["", a]:
 			if len(st) < 5 and len(lis) == 1:
 				#check if we havent just randomly found the string in another word
 				#if (" " + st + " ") in lis[0] or (lis[0].endswith(" " + st)) or (lis[0].startswith(st + " ")):
@@ -690,42 +681,30 @@ def get_predefined_rulesets():
 
 	rulesets = []
 
-	for f in os.listdir(datadir("rules/predefined")):
+	for f in os.listdir(data_dir['rules']("predefined")):
 		if f.endswith(".tsv"):
 
 			rawf = f.replace(".tsv","")
-			valid = True
-			for char in rawf:
-				if char not in validchars:
-					valid = False
-					break # don't even show up invalid filenames
-
+			valid = all(char in validchars for char in rawf)
 			if not valid: continue
-			if not "_" in rawf: continue
+			if "_" not in rawf: continue
 
 			try:
-				with open(datadir("rules/predefined",f)) as tsvfile:
+				with open(data_dir['rules']("predefined",f)) as tsvfile:
 					line1 = tsvfile.readline()
 					line2 = tsvfile.readline()
 
 					if "# NAME: " in line1:
 						name = line1.replace("# NAME: ","")
 					else: name = rawf.split("_")[1]
-					if "# DESC: " in line2:
-						desc = line2.replace("# DESC: ","")
-					else: desc = ""
-
+					desc = line2.replace("# DESC: ","") if "# DESC: " in line2 else ""
 					author = rawf.split("_")[0]
 			except:
 				continue
 
 			ruleset = {"file":rawf}
 			rulesets.append(ruleset)
-			if os.path.exists(datadir("rules",f)):
-				ruleset["active"] = True
-			else:
-				ruleset["active"] = False
-
+			ruleset["active"] = bool(os.path.exists(data_dir['rules'](f)))
 			ruleset["name"] = name
 			ruleset["author"] = author
 			ruleset["desc"] = desc
@@ -774,10 +753,15 @@ def build_db():
 
 
 	# parse files
-	db = tsv.parse_all(datadir("scrobbles"),"int","string","string",comments=False)
+	db = tsv.parse_all(data_dir['scrobbles'](),"int","string","string",comments=False)
 	scrobblenum = len(db)
 	log(f"Found {scrobblenum} scrobbles...")
-	pbar = ProgressBar(max=scrobblenum,prefix="Loading scrobbles")
+
+	usebar = not settings.get_settings("CLEAN_OUTPUT")
+	if usebar: pbar = ProgressBar(max=scrobblenum,prefix="Loading scrobbles")
+	else:
+		n = 0
+		m = max(int(scrobblenum / 25),20)
 	#db = parseAllTSV("scrobbles","int","string","string",escape=False)
 	for sc in db:
 		artists = sc[1].split("␟")
@@ -785,9 +769,12 @@ def build_db():
 		time = sc[0]
 
 		readScrobble(artists,title,time)
-		pbar.progress()
+		if usebar: pbar.progress()
+		else:
+			n += 1
+			if n % m == 0: log(f"Loaded {n}/{scrobblenum}...")
 
-	pbar.done()
+	if usebar: pbar.done()
 	log("Database loaded, optimizing...")
 
 	# optimize database
@@ -797,7 +784,7 @@ def build_db():
 	STAMPS.sort()
 
 	# inform malojatime module about earliest scrobble
-	if len(STAMPS) > 0: register_scrobbletime(STAMPS[0])
+	if STAMPS: register_scrobbletime(STAMPS[0])
 
 	# NOT NEEDED BECAUSE WE DO THAT ON ADDING EVERY ARTIST ANYWAY
 	# get extra artists with no real scrobbles from countas rules
@@ -856,7 +843,7 @@ def sync():
 	#log("Sorted into months",module="debug")
 
 	for e in entries:
-		tsv.add_entries(datadir("scrobbles/" + e + ".tsv"),entries[e],comments=False)
+		tsv.add_entries(data_dir['scrobbles'](e + ".tsv"),entries[e],comments=False)
 		#addEntries("scrobbles/" + e + ".tsv",entries[e],escape=False)
 
 	#log("Written files",module="debug")
@@ -1147,20 +1134,13 @@ def db_aggregate_full(by=None,since=None,to=None,within=None,timerange=None,arti
 
 # Search for strings
 def db_search(query,type=None):
+	results = []
 	if type=="ARTIST":
-		results = []
-		for a in ARTISTS:
-			#if query.lower() in a.lower():
-			if simplestr(query) in simplestr(a):
-				results.append(a)
-
+		results = [a for a in ARTISTS if simplestr(query) in simplestr(a)]
 	if type=="TRACK":
-		results = []
-		for t in TRACKS:
-			#if query.lower() in t[1].lower():
-			if simplestr(query) in simplestr(t[1]):
-				results.append(get_track_dict(t))
-
+		results = [
+		    get_track_dict(t) for t in TRACKS if simplestr(query) in simplestr(t[1])
+		]
 	return results
 
 
@@ -1219,7 +1199,7 @@ def scrobbles_in_range(start,end,reverse=False):
 # for performance testing
 def generateStuff(num=0,pertrack=0,mult=0):
 	import random
-	for i in range(num):
+	for _ in range(num):
 		track = random.choice(TRACKS)
 		t = get_track_dict(track)
 		time = random.randint(STAMPS[0],STAMPS[-1])
@@ -1227,7 +1207,7 @@ def generateStuff(num=0,pertrack=0,mult=0):
 
 	for track in TRACKS:
 		t = get_track_dict(track)
-		for i in range(pertrack):
+		for _ in range(pertrack):
 			time = random.randint(STAMPS[0],STAMPS[-1])
 			createScrobble(t["artists"],t["title"],time,volatile=True)
 
